@@ -82,6 +82,16 @@ def fDte_formatToDate(dte_date, str_dateFormat = '%Y-%m-%d', bl_stopLoop = False
         raise
     return dte_formatToDate
 
+def fDte_formatToTimeStamp(dte_date):
+    try:
+        dte_formatToDate = dt.datetime.fromtimestamp
+    except Exception as err:
+        print(' ERROR in fDte_formatToTimeStamp')
+        print(' - Error: ', err)
+        print(' - dte_date: ', dte_date)
+        raise
+    return dte_formatToDate
+
 def fDte_convertExcelInteger(int_dateEexcel, bl_formatDate_tuple = False):
     try:
         dte_base1900 = dt.datetime(1900, 1, 1)
